/*
 * IIdentification.java
 *
 * Created on December 4, 2002, 5:24 PM
 */

package CollabUtils;

import java.util.GregorianCalendar;

/** Methods which supply facts about the application.
 *
 * All methods should return a string of readable English text with the information
 * suggested by the method name.  Although restrictions on length or content
 * cannot be enforced by the interface, the implementor is urged to abide
 * by any specific guidelines listed with the method.  As a general rule, 
 * return strings may contain internal white space, but should
 * leave surrounding white space decisions to the client.
 * It is acceptable for the "detail" methods to return the same value as the
 * non-detail methods.
 *
 */
public interface IApplicationIdentification {
    
    /** Return a (short) string identifying the authors of the program.
     * NOTE FOR CSE143 PROJECT 4: DO NOT GIVE PERSONAL INFORMATION UNLESS YOU
     * ARE COMFORTABLE WITH THE WHOLE WORLD SEEING IT!  A code name or nickname
     * is sufficient.
     */
    public String getApplicationAuthor();
    
    /** return a string (as long as desired) identifying the authors of the program.
     */
    public String getApplicationAuthorDetails();
    
    /** return the date of creation or update
     */
    public GregorianCalendar getApplicationDate();
    
    /** return a (short) description of the application.
     */
    public String getApplicationDescription();
    
    /** return a string (as long as desired) describing the application
     */
    public String getApplicationDescriptionDetails();
    
    /** return a string (as long as desired) giving any details of
     *usage or applicability which the author wishes to convey to
     *a user or a client.
     */
    public String getUsageInformation();
    
// end IApplicationIdentification    
}
